#!/bin/bash

# Copyright (C) 2023, Xilinx Inc - All rights reserved
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may
# not use this file except in compliance with the License. A copy of the
# License is located at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

echo "Number of args $#"

helper_func()
{
   echo ""
   echo "Usage:-"
   echo "    $0"
   echo "        or"
   echo "    $0 \"Absolute path of ma35/build folder\""
}

# override if MA35 build path is specified as argument
if [ $# -gt 1 ]
then
    helper_func
    exit 1
fi

# Modify below paths as per your test requirements
echo "############## Modify below path by sending as an argument ##############"
MA35_BUILD_PATH=$PWD
if [ $# -gt 0 ]
then
    MA35_BUILD_PATH=$1
fi
echo "MA35_BUILD_PATH: " $MA35_BUILD_PATH
echo "#########################################################################"
echo ""

echo "###################### RUN XRM DAEMON ###################################"
pkill -9 xrmd
$MA35_BUILD_PATH/_deps/xrm-build/xrmd --live &
sleep 1
echo "#########################################################################"
echo ""

echo "#################### Load XRM host plugins ##############################"
XRM_JSON=\
'{
    "request": {
        "name": "loadXrmPlugins",
        "requestId": 1,
        "parameters": [
            {
            "xrmPluginFileName": "'"$MA35_BUILD_PATH"'/_deps/xrm_plugins-build/scaler/libxrm_scaler_plugin.so",
            "xrmPluginName": "xrmMA35ScalePlugin"
            },
            {
            "xrmPluginFileName": "'"$MA35_BUILD_PATH"'/_deps/xrm_plugins-build/decoder/libxrm_decoder_plugin.so",
            "xrmPluginName": "xrmMA35DecodePlugin"
            },
            {
            "xrmPluginFileName": "'"$MA35_BUILD_PATH"'/_deps/xrm_plugins-build/encoder/libxrm_encoder_plugin.so",
            "xrmPluginName": "xrmMA35EncodePlugin"
            },
            {
            "xrmPluginFileName": "'"$MA35_BUILD_PATH"'/_deps/xrm_plugins-build/ml/libxrm_ml_plugin.so",
            "xrmPluginName": "xrmMA35MLPlugin"
            }
        ]
    }
}'
echo $XRM_JSON > $MA35_BUILD_PATH/xrm_plugins.json
chmod 777 $MA35_BUILD_PATH/_deps/xrm-src/src/cli/xrmadm
$MA35_BUILD_PATH/_deps/xrm-src/src/cli/xrmadm $MA35_BUILD_PATH/xrm_plugins.json
echo "#########################################################################"
echo ""

echo "################## Check Device/CUs status ##############################"
$MA35_BUILD_PATH/_deps/xrm-src/src/cli/xrmadm $MA35_BUILD_PATH/_deps/xrm-src/test/list_cmd.json
echo "#########################################################################"
echo ""

echo "##################### Set FFMPEG Exe path ###############################"
PATH="$MA35_BUILD_PATH/_deps/ffmpeg-build:$PATH"
whereis ffmpeg
PATH="$MA35_BUILD_PATH/_deps/apps-build/xma_apps/decoder:$PATH"
PATH="$MA35_BUILD_PATH/_deps/apps-build/xma_apps/encoder:$PATH"
PATH="$MA35_BUILD_PATH/_deps/apps-build/xma_apps/scaler:$PATH"
PATH="$MA35_BUILD_PATH/_deps/apps-build/xma_apps/transcoder:$PATH"
echo "#########################################################################"
echo ""

################################################
################ JOB SLOT TOOL #################
################################################
echo "################### Job Slot Tool tests started #########################"
# Run Job Slot test script
JOBSLOT_SOURCE_PATH="$MA35_BUILD_PATH/jobslot_reservation"
source $JOBSLOT_SOURCE_PATH/run_jobslot_commands.sh
echo "################### Job Slot Tool tests completed #######################"
echo ""

################################################
################ LAUNCHER APP ##################
################################################
# Run Launcher App test script
echo "##################### Launcher App tests started ########################"
LAUNCHER_SOURCE_PATH="$MA35_BUILD_PATH/launcher"
source $LAUNCHER_SOURCE_PATH/run_launcher_commands.sh
echo "#################### Launcher App tests completed #######################"
echo ""

echo "All tests completed."
